@@ -1,9 +1,9 @@
 """
 Author: Damien GUEHO
-Copyright: Copyright (C) 2021 Damien GUEHO
+Copyright: Copyright (C) 2022 Damien GUEHO
 License: Public Domain
-Version: 20
-Date: November 2021
+Version: 23
+Date: April 2022
 Python: 3.7.7
 """
 
@@ -13,7 +13,7 @@ import numpy as np
 from scipy.integrate import odeint
 from scipy.interpolate import interp1d
 
-from ClassesGeneral.ClassSignal import DiscreteSignal
+from systemID.ClassesGeneral.ClassSignal import DiscreteSignal
 
 
 class PanelFlutterDynamics:
@@ -94,10 +94,10 @@ class PanelFlutterDynamics:
 
 """
 Author: Damien GUEHO
-Copyright: Copyright (C) 2021 Damien GUEHO
+Copyright: Copyright (C) 2022 Damien GUEHO
 License: Public Domain
-Version: 20
-Date: November 2021
+Version: 23
+Date: April 2022
 Python: 3.7.7
 """
 
@@ -107,7 +107,7 @@ import numpy as np
 from scipy.integrate import odeint
 from scipy.interpolate import interp1d
 
-from ClassesGeneral.ClassSignal import DiscreteSignal
+from systemID.ClassesGeneral.ClassSignal import DiscreteSignal
 
 
 class PanelFlutterDynamics2:
@@ -187,10 +187,10 @@ class PanelFlutterDynamics2:
 
 """
 Author: Damien GUEHO
-Copyright: Copyright (C) 2021 Damien GUEHO
+Copyright: Copyright (C) 2022 Damien GUEHO
 License: Public Domain
-Version: 20
-Date: November 2021
+Version: 23
+Date: April 2022
 Python: 3.7.7
 """
 
@@ -200,7 +200,7 @@ import numpy as np
 from scipy.integrate import odeint
 from scipy.interpolate import interp1d
 
-from ClassesGeneral.ClassSignal import DiscreteSignal
+from systemID.ClassesGeneral.ClassSignal import DiscreteSignal
 
 
 class PanelFlutterDynamics3:
