@@ -1,9 +1,9 @@
 """
 Author: Damien GUEHO
-Copyright: Copyright (C) 2021 Damien GUEHO
+Copyright: Copyright (C) 2022 Damien GUEHO
 License: Public Domain
-Version: 20
-Date: November 2021
+Version: 23
+Date: April 2022
 Python: 3.7.7
 """
 
@@ -126,11 +126,19 @@ class ContinuousSignal(Signal):
             self.u = u
         elif self.signal_shape == 'External':
             def zero(t):
-                return np.zeros(self.dimension) * t
+                data = np.outer(np.zeros(self.dimension), t)
+                if data.shape[1] == 1:
+                    return data[:, 0]
+                else:
+                    return data
             self.u = kwargs.get('u', zero)
         else:
             def zero(t):
-                return np.zeros(self.dimension) * t
+                data = np.outer(np.zeros(self.dimension), t)
+                if data.shape[1] == 1:
+                    return data[:, 0]
+                else:
+                    return data
             self.u = zero
 
 
@@ -155,9 +163,9 @@ class OutputSignal(DiscreteSignal):
         if signal.signal_type == 'Continuous':
 
             tspan = kwargs.get('tspan', np.array([0, 1]))
-            total_time = tspan[-1]
+            total_time = kwargs.get('total_time', tspan[-1])
             number_steps = len(tspan)
-            frequency = int(round((number_steps - 1) / total_time))
+            frequency = kwargs.get('frequency', round((number_steps - 1) / total_time, 6))
 
             observer = kwargs.get('observer', False)
             reference_output_signal = kwargs.get('reference_output_signal', np.zeros([system.output_dimension, number_steps]))
