@@ -1,9 +1,9 @@
 """
 Author: Damien GUEHO
-Copyright: Copyright (C) 2021 Damien GUEHO
+Copyright: Copyright (C) 2022 Damien GUEHO
 License: Public Domain
-Version: 20
-Date: November 2021
+Version: 23
+Date: April 2022
 Python: 3.7.7
 """
 
@@ -11,7 +11,7 @@ Python: 3.7.7
 from systemID.SystemIDAlgorithms.QMarkovCover import qMarkovCover
 
 
-class ERA:
+class QMarkov:
     def __init__(self, markov_parameters, covariance_parameters, Q, state_dimension, **kwargs):
         self.A, self.B, self.C, self.D = qMarkovCover(markov_parameters, covariance_parameters, Q, state_dimension, **kwargs)
 
