@@ -1,9 +1,9 @@
 """
 Author: Damien GUEHO
-Copyright: Copyright (C) 2021 Damien GUEHO
+Copyright: Copyright (C) 2022 Damien GUEHO
 License: Public Domain
-Version: 20
-Date: November 2021
+Version: 23
+Date: April 2022
 Python: 3.7.7
 """
 
@@ -21,7 +21,7 @@ from ClassesGeneral.ClassSignal import DiscreteSignal, subtract2Signals
 
 def sparseApproximation1stOrder(signals, input_signals, x0s_testing, input_signals_testing, order, max_order, post_treatment, l1, alpha, delta, epsilon, max_iterations, shift):
 
-    # Get signals parameters - All signals have same dimension
+    # Get signal parameters - All signal have same dimension
     number_signals = len(signals)
     dimension = signals[0].dimension
     frequencies = []
@@ -191,7 +191,7 @@ def sparseApproximation1stOrder(signals, input_signals, x0s_testing, input_signa
     # THETA_SPARSE[12, 3] = -3896.36363
     # THETA_SPARSE[35, 3] = -0.76157
 
-    ## Calculation resulting signals
+    ## Calculation resulting signal
     print('Calculating xLS')
     print('Calculating xSPARSE')
 
@@ -319,10 +319,10 @@ def sparseApproximation1stOrder(signals, input_signals, x0s_testing, input_signa
 
 # """
 # Author: Damien GUEHO
-# Copyright: Copyright (C) 2021 Damien GUEHO
+# Copyright: Copyright (C) 2022 Damien GUEHO
 # License: Public Domain
-# Version: 20
-# Date: November 2021
+# Version: 23
+# Date: April 2022
 # Python: 3.7.7
 # """
 #
@@ -338,11 +338,11 @@ def sparseApproximation1stOrder(signals, input_signals, x0s_testing, input_signa
 # from ClassesGeneral.ClassSignal import DiscreteSignal, subtract2Signals
 #
 #
-# def sparseApproximation1stOrder(signals, input_signals, order, max_order, post_treatment, l1, alpha, delta, epsilon, max_iterations, shift):
+# def sparseApproximation1stOrder(signal, input_signals, order, max_order, post_treatment, l1, alpha, delta, epsilon, max_iterations, shift):
 #
-#     # Get signals parameters - All signals have same dimension
-#     number_signals = len(signals)
-#     dimension = signals[0].dimension
+#     # Get signal parameters - All signal have same dimension
+#     number_signals = len(signal)
+#     dimension = signal[0].dimension
 #     frequencies = []
 #     total_times = []
 #     numbers_steps = []
@@ -353,13 +353,13 @@ def sparseApproximation1stOrder(signals, input_signals, x0s_testing, input_signa
 #     interp_inputs = []
 #
 #     for s in range(number_signals):
-#         frequencies.append(signals[s].frequency)
-#         total_times.append(signals[s].total_time)
-#         numbers_steps.append(signals[s].number_steps)
-#         tspan = np.linspace(0, signals[s].total_time, signals[s].number_steps)
+#         frequencies.append(signal[s].frequency)
+#         total_times.append(signal[s].total_time)
+#         numbers_steps.append(signal[s].number_steps)
+#         tspan = np.linspace(0, signal[s].total_time, signal[s].number_steps)
 #         tspans.append(tspan)
-#         data.append(signals[s].data)
-#         interp_data.append(interp1d(tspan, signals[s].data, kind='previous'))
+#         data.append(signal[s].data)
+#         interp_data.append(interp1d(tspan, signal[s].data, kind='previous'))
 #         inputs.append(input_signals[s].data)
 #         interp_inputs.append(interp1d(tspan, input_signals[s].data, kind='previous'))
 #
@@ -490,7 +490,7 @@ def sparseApproximation1stOrder(signals, input_signals, x0s_testing, input_signa
 #     #                 count = count + 1
 #     #
 #     #
-#     # ## Calculation resulting signals
+#     # ## Calculation resulting signal
 #     # print('Calculating xLS')
 #     # print('Calculating xSPARSE')
 #
