@@ -1,9 +1,9 @@
 """
 Author: Damien GUEHO
-Copyright: Copyright (C) 2021 Damien GUEHO
+Copyright: Copyright (C) 2022 Damien GUEHO
 License: Public Domain
-Version: 20
-Date: November 2021
+Version: 23
+Date: April 2022
 Python: 3.7.7
 """
 
@@ -14,7 +14,26 @@ from numpy import linalg as LA
 from systemID.SystemIDAlgorithms.GetPowerOf2 import findPreviousPowerOf2
 
 
-def getMarkovParametersFromFrequencyRepsonseFunctions(experiments):
+def getMarkovParametersFromFrequencyResponseFunctions(experiments):
+    """
+    Purpose:
+
+
+    Parameters:
+        -
+
+    Returns:
+        -
+
+    Imports:
+        -
+
+    Description:
+
+
+    See Also:
+        -
+    """
 
     # Parameters
     number_experiments = experiments.number_experiments
