@@ -1,9 +1,9 @@
 """
 Author: Damien GUEHO
-Copyright: Copyright (C) 2021 Damien GUEHO
+Copyright: Copyright (C) 2022 Damien GUEHO
 License: Public Domain
-Version: 20
-Date: November 2021
+Version: 23
+Date: April 2022
 Python: 3.7.7
 """
 
@@ -14,6 +14,25 @@ import scipy.linalg as LA
 
 
 def getTVObserverGainMarkovParametersFromTVObserverMarkovParameters(hki_observer2, observer_order):
+    """
+    Purpose:
+
+
+    Parameters:
+        -
+
+    Returns:
+        -
+
+    Imports:
+        -
+
+    Description:
+
+
+    See Also:
+        -
+    """
 
     # Dimension and number of steps
     output_dimension = int(hki_observer2.shape[1] / observer_order)
