@@ -1,9 +1,9 @@
 """
 Author: Damien GUEHO
-Copyright: Copyright (C) 2021 Damien GUEHO
+Copyright: Copyright (C) 2022 Damien GUEHO
 License: Public Domain
-Version: 20
-Date: November 2021
+Version: 23
+Date: April 2022
 Python: 3.7.7
 """
 
@@ -13,6 +13,28 @@ from scipy.integrate import odeint
 
 
 def higherOrderStateTransitionTensorsPropagation(sensitivities, F, u, x0, tspan):
+    """
+        Purpose:
+            This program computes the time evolution of the state-transition matrix and higher-order state-transition tensors of a dynamical system,
+            given its sensitivities and a nominal trajectory.
+
+        Parameters:
+            - **sensitivities** (``list``): sensitivities of the considered dynamical system.
+
+        Returns:
+            - **A_vec** (``ndarray``):
+            - **state_transition_tensors** (``list``):
+
+        Imports:
+            - ``import numpy as np``
+            - ``from scipy.integrate import odeint``
+
+        Description:
+
+
+        See Also:
+            -
+    """
 
     ## Order of the expansion and dimension of the system
     order = len(sensitivities)
@@ -46,9 +68,15 @@ def higherOrderStateTransitionTensorsPropagation(sensitivities, F, u, x0, tspan)
             Phi1_tensor = Phi[state_dimension:].reshape(state_dimension, state_dimension)
             return np.concatenate((dxdt, np.tensordot(Ac1(x, t, u), Phi1_tensor, axes=([1], [0])).reshape(state_dimension ** 2)))
 
-        A_vec = odeint(dPhi, np.concatenate((x0, Phi1.reshape(state_dimension**2))), tspan, rtol=1e-13, atol=1e-13)
+        Phi0 = Phi1.reshape(state_dimension**2)
+        A_vec = odeint(dPhi, np.concatenate((x0, Phi0)), tspan, rtol=1e-13, atol=1e-13)
 
-        return A_vec
+        state_transition_tensor1 = np.zeros([state_dimension, state_dimension, number_steps])
+        for k in range(number_steps):
+            state_transition_tensor1[:, :, k] = A_vec[k, state_dimension:].reshape(state_dimension, state_dimension)
+        state_transition_tensors = [state_transition_tensor1]
+
+        return A_vec, state_transition_tensors
 
 
     if order == 2:
@@ -62,9 +90,17 @@ def higherOrderStateTransitionTensorsPropagation(sensitivities, F, u, x0, tspan)
             dPhi2_tensor = np.tensordot(Ac1(x, t, u), Phi2_tensor, axes=([1], [0])) + np.tensordot(Ac2(x, t, u), np.tensordot(Phi1_tensor, Phi1_tensor, axes=0), axes=([1, 2], [0, 2]))
             return np.concatenate((dxdt, np.concatenate((dPhi1_tensor.reshape(state_dimension ** 2), dPhi2_tensor.reshape(state_dimension ** 3)))))
 
-        A_vec = odeint(dPhi, np.concatenate((x0, np.concatenate((Phi1.reshape(state_dimension ** 2), Phi2.reshape(state_dimension ** 3))))), tspan, rtol=1e-13, atol=1e-13)
+        Phi0 = np.concatenate((Phi1.reshape(state_dimension ** 2), Phi2.reshape(state_dimension ** 3)))
+        A_vec = odeint(dPhi, np.concatenate((x0, Phi0)), tspan, rtol=1e-13, atol=1e-13)
 
-        return A_vec
+        state_transition_tensor1 = np.zeros([state_dimension, state_dimension, number_steps])
+        state_transition_tensor2 = np.zeros([state_dimension, state_dimension, state_dimension, number_steps])
+        for k in range(number_steps):
+            state_transition_tensor1[:, :, k] = A_vec[k, state_dimension:state_dimension + state_dimension ** 2].reshape(state_dimension, state_dimension)
+            state_transition_tensor2[:, :, :, k] = A_vec[k, state_dimension + state_dimension ** 2:].reshape(state_dimension, state_dimension, state_dimension)
+        state_transition_tensors = [state_transition_tensor1, state_transition_tensor2]
+
+        return A_vec, state_transition_tensors
 
 
     if order == 3:
@@ -86,9 +122,19 @@ def higherOrderStateTransitionTensorsPropagation(sensitivities, F, u, x0, tspan)
 
             return np.concatenate((dxdt, np.concatenate((dPhi1_tensor.reshape(state_dimension ** 2), dPhi2_tensor.reshape(state_dimension ** 3), dPhi3_tensor.reshape(state_dimension ** 4)))))
 
-        A_vec = odeint(dPhi, np.concatenate((x0, np.concatenate((Phi1.reshape(state_dimension ** 2), Phi2.reshape(state_dimension ** 3), Phi3.reshape(state_dimension ** 4))))), tspan, rtol=1e-13, atol=1e-13)
+        Phi0 = np.concatenate((Phi1.reshape(state_dimension ** 2), Phi2.reshape(state_dimension ** 3), Phi3.reshape(state_dimension ** 4)))
+        A_vec = odeint(dPhi, np.concatenate((x0, Phi0)), tspan, rtol=1e-13, atol=1e-13)
 
-        return A_vec
+        state_transition_tensor1 = np.zeros([state_dimension, state_dimension, number_steps])
+        state_transition_tensor2 = np.zeros([state_dimension, state_dimension, state_dimension, number_steps])
+        state_transition_tensor3 = np.zeros([state_dimension, state_dimension, state_dimension, state_dimension, number_steps])
+        for k in range(number_steps):
+            state_transition_tensor1[:, :, k] = A_vec[k, state_dimension:state_dimension + state_dimension ** 2].reshape(state_dimension, state_dimension)
+            state_transition_tensor2[:, :, :, k] = A_vec[k, state_dimension + state_dimension ** 2:state_dimension + state_dimension ** 2 + state_dimension ** 3].reshape(state_dimension, state_dimension, state_dimension)
+            state_transition_tensor3[:, :, :, :, k] = A_vec[k, state_dimension + state_dimension ** 2 + state_dimension ** 3:].reshape(state_dimension, state_dimension, state_dimension, state_dimension)
+        state_transition_tensors = [state_transition_tensor1, state_transition_tensor2, state_transition_tensor3]
+
+        return A_vec, state_transition_tensors
 
 
     if order == 4:
@@ -131,9 +177,20 @@ def higherOrderStateTransitionTensorsPropagation(sensitivities, F, u, x0, tspan)
             return np.concatenate((dxdt, np.concatenate((dPhi1_tensor.reshape(state_dimension ** 2), dPhi2_tensor.reshape(state_dimension ** 3), dPhi3_tensor.reshape(state_dimension ** 4), dPhi4_tensor.reshape(state_dimension ** 5)))))
 
         Phi0 = np.concatenate((Phi1.reshape(state_dimension ** 2), Phi2.reshape(state_dimension ** 3), Phi3.reshape(state_dimension ** 4), Phi4.reshape(state_dimension ** 5)))
-        A_vec = odeint(dPhi, np.concatenate((x0, Phi0)), tspan, rtol=1e-12, atol=1e-12)
+        A_vec = odeint(dPhi, np.concatenate((x0, Phi0)), tspan, rtol=1e-13, atol=1e-13)
 
-    return A_vec
+        state_transition_tensor1 = np.zeros([state_dimension, state_dimension, number_steps])
+        state_transition_tensor2 = np.zeros([state_dimension, state_dimension, state_dimension, number_steps])
+        state_transition_tensor3 = np.zeros([state_dimension, state_dimension, state_dimension, state_dimension, number_steps])
+        state_transition_tensor4 = np.zeros([state_dimension, state_dimension, state_dimension, state_dimension, state_dimension, number_steps])
+        for k in range(number_steps):
+            state_transition_tensor1[:, :, k] = A_vec[k, state_dimension:state_dimension + state_dimension ** 2].reshape(state_dimension, state_dimension)
+            state_transition_tensor2[:, :, :, k] = A_vec[k, state_dimension + state_dimension ** 2:state_dimension + state_dimension ** 2 + state_dimension ** 3].reshape(state_dimension, state_dimension, state_dimension)
+            state_transition_tensor3[:, :, :, :, k] = A_vec[k, state_dimension + state_dimension ** 2 + state_dimension ** 3:state_dimension + state_dimension ** 2 + state_dimension ** 3 + state_dimension ** 4].reshape(state_dimension, state_dimension, state_dimension, state_dimension)
+            state_transition_tensor4[:, :, :, :, :, k] = A_vec[k, state_dimension + state_dimension ** 2 + state_dimension ** 3 + state_dimension ** 4:].reshape(state_dimension, state_dimension, state_dimension, state_dimension, state_dimension)
+        state_transition_tensors = [state_transition_tensor1, state_transition_tensor2, state_transition_tensor3, state_transition_tensor4]
+
+    return A_vec, state_transition_tensors
 
 
 
