@@ -1,9 +1,9 @@
 """
 Author: Damien GUEHO
-Copyright: Copyright (C) 2021 Damien GUEHO
+Copyright: Copyright (C) 2022 Damien GUEHO
 License: Public Domain
-Version: 20
-Date: November 2021
+Version: 23
+Date: April 2022
 Python: 3.7.7
 """
 
@@ -12,15 +12,35 @@ import numpy as np
 from scipy.integrate import odeint
 
 from systemID.SystemIDAlgorithms.Integrate import integrate
+from systemID.SystemIDAlgorithms.HigherOrderStateTransitionTensorsPropagation import higherOrderStateTransitionTensorsPropagation
 
 
 def propagation(signal, system, **kwargs):
+    """
+    Purpose:
+
+
+    Parameters:
+        -
+
+    Returns:
+        -
+
+    Imports:
+        -
+
+    Description:
+
+
+    See Also:
+        -
+    """
 
     # Get system's parameters
     state_dimension = system.state_dimension
     output_dimension = system.output_dimension
     x0 = system.x0
-    initial_states = system.initial_states
+    initial_states = [(x0, 0)]
     number_initial_states = len(initial_states)
 
     # Propagate depending on system type
@@ -323,7 +343,7 @@ def propagation(signal, system, **kwargs):
             integration_step = kwargs.get('integration_step', 0.001)
             sol = integrate(dynamics, x0, tspan, integration_step, args=(signal.u, ))
         else:
-            sol = odeint(dynamics, x0, tspan, args=(signal.u, ), rtol=1e-13, atol=1e-13)
+            sol = odeint(dynamics, x0, tspan, args=(signal.u, ), rtol=1e-12, atol=1e-12)
 
         x = sol.T
         y = np.zeros([output_dimension, tspan.shape[0]])
@@ -345,7 +365,7 @@ def propagation(signal, system, **kwargs):
             integration_step = kwargs.get('integration_step', 0.001)
             sol = integrate(dynamics, x0, tspan, integration_step, args=(signal.u, ))
         else:
-            sol = odeint(dynamics, x0, tspan, args=(signal.u, ), rtol=1e-13, atol=1e-13)
+            sol = odeint(dynamics, x0, tspan, args=(signal.u, ), rtol=1e-12, atol=1e-12)
 
         x = sol.T
         y = np.zeros([output_dimension, tspan.shape[0]])
@@ -364,7 +384,7 @@ def propagation(signal, system, **kwargs):
             integration_step = kwargs.get('integration_step', 0.001)
             sol = integrate(F, x0, tspan, integration_step, args=(signal.u, ))
         else:
-            sol = odeint(F, x0, tspan, args=(signal.u,), rtol=1e-13, atol=1e-13)
+            sol = odeint(F, x0, tspan, args=(signal.u,), rtol=1e-12, atol=1e-12)
 
         x = sol.T
         y = np.zeros([output_dimension, tspan.shape[0]])
@@ -375,9 +395,12 @@ def propagation(signal, system, **kwargs):
 
 
     if system_type == 'Continuous Nonlinear Higher Order Expansion':
+
         tspan = kwargs.get('tspan', np.zeros(1))
         number_steps = len(tspan)
 
+        A_vec, _ = higherOrderStateTransitionTensorsPropagation(system.sensitivities, system.F, system.u_nominal, system.x0_nominal, tspan)
+
         G = system.G
 
         x = np.zeros([state_dimension, number_steps])
@@ -386,33 +409,33 @@ def propagation(signal, system, **kwargs):
 
         if system.order == 1:
             for i in range(number_steps):
-                A1 = system.A_vec[i, state_dimension:state_dimension + state_dimension ** 2].reshape(state_dimension, state_dimension)
+                A1 = A_vec[i, state_dimension:state_dimension + state_dimension ** 2].reshape(state_dimension, state_dimension)
                 x[:, i] = np.matmul(A1, x0)
                 y[:, i] = G(x[:, i], tspan[i], signal.u(tspan[i]))
 
         if system.order == 2:
             for i in range(number_steps):
-                A1 = system.A_vec[i, state_dimension:state_dimension + state_dimension ** 2].reshape(state_dimension, state_dimension)
-                A2 = system.A_vec[i, state_dimension + state_dimension ** 2:].reshape(state_dimension, state_dimension, state_dimension)
+                A1 = A_vec[i, state_dimension:state_dimension + state_dimension ** 2].reshape(state_dimension, state_dimension)
+                A2 = A_vec[i, state_dimension + state_dimension ** 2:].reshape(state_dimension, state_dimension, state_dimension)
                 x[:, i] = np.matmul(A1, x0) + (1 / 2) * np.tensordot(A2, np.tensordot(x0, x0, axes=0), axes=([1, 2], [0, 1]))
                 y[:, i] = G(x[:, i], tspan[i], signal.u(tspan[i]))
 
         if system.order == 3:
             for i in range(number_steps):
-                A1 = system.A_vec[i, state_dimension:state_dimension + state_dimension ** 2].reshape(state_dimension, state_dimension)
-                A2 = system.A_vec[i, state_dimension + state_dimension ** 2:state_dimension + state_dimension ** 2 + state_dimension ** 3].reshape(state_dimension, state_dimension, state_dimension)
-                A3 = system.A_vec[i, state_dimension + state_dimension ** 2 + state_dimension ** 3:].reshape(state_dimension, state_dimension, state_dimension, state_dimension)
+                A1 = A_vec[i, state_dimension:state_dimension + state_dimension ** 2].reshape(state_dimension, state_dimension)
+                A2 = A_vec[i, state_dimension + state_dimension ** 2:state_dimension + state_dimension ** 2 + state_dimension ** 3].reshape(state_dimension, state_dimension, state_dimension)
+                A3 = A_vec[i, state_dimension + state_dimension ** 2 + state_dimension ** 3:].reshape(state_dimension, state_dimension, state_dimension, state_dimension)
                 x[:, i] = np.matmul(A1, x0) + (1 / 2) * np.tensordot(A2, np.tensordot(x0, x0, axes=0), axes=([1, 2], [0, 1])) + (1 / 6) * np.tensordot(A3, np.tensordot(np.tensordot(x0, x0, axes=0), x0, axes=0), axes=([1, 2, 3], [0, 1, 2]))
                 y[:, i] = G(x[:, i], tspan[i], signal.u(tspan[i]))
 
         if system.order == 4:
             for i in range(number_steps):
-                A1 = system.A_vec[i, state_dimension:state_dimension + state_dimension ** 2].reshape(state_dimension, state_dimension)
-                A2 = system.A_vec[i, state_dimension + state_dimension ** 2:state_dimension + state_dimension ** 2 + state_dimension ** 3].reshape(state_dimension, state_dimension, state_dimension)
-                A3 = system.A_vec[i, state_dimension + state_dimension ** 2 + state_dimension ** 3:state_dimension + state_dimension ** 2 + state_dimension ** 3 + state_dimension ** 4].reshape(state_dimension, state_dimension, state_dimension, state_dimension)
-                A4 = system.A_vec[i, state_dimension + state_dimension ** 2 + state_dimension ** 3 + state_dimension ** 4:].reshape(state_dimension, state_dimension, state_dimension, state_dimension, state_dimension)
+                A1 = A_vec[i, state_dimension:state_dimension + state_dimension ** 2].reshape(state_dimension, state_dimension)
+                A2 = A_vec[i, state_dimension + state_dimension ** 2:state_dimension + state_dimension ** 2 + state_dimension ** 3].reshape(state_dimension, state_dimension, state_dimension)
+                A3 = A_vec[i, state_dimension + state_dimension ** 2 + state_dimension ** 3:state_dimension + state_dimension ** 2 + state_dimension ** 3 + state_dimension ** 4].reshape(state_dimension, state_dimension, state_dimension, state_dimension)
+                A4 = A_vec[i, state_dimension + state_dimension ** 2 + state_dimension ** 3 + state_dimension ** 4:].reshape(state_dimension, state_dimension, state_dimension, state_dimension, state_dimension)
                 x[:, i] = np.matmul(A1, x0) + (1 / 2) * np.tensordot(A2, np.tensordot(x0, x0, axes=0), axes=([1, 2], [0, 1])) + (1 / 6) * np.tensordot(A3, np.tensordot(np.tensordot(x0, x0, axes=0), x0, axes=0), axes=([1, 2, 3], [0, 1, 2])) + (1 / 24) * np.tensordot(A4, np.tensordot(np.tensordot(np.tensordot(x0, x0, axes=0), x0, axes=0), x0, axes=0), axes=([1, 2, 3, 4], [0, 1, 2, 3]))
                 y[:, i] = G(x[:, i], tspan[i], signal.u(tspan[i]))
 
 
-    return (y, x)
+    return y, x
